@@ -9,7 +9,7 @@ import pysyncrosim as ps
 from pysyncrosim import helper
 from pysyncrosim.environment import _environment
 
-pd.set_option("max_columns", 5)
+pd.set_option("display.max_columns", 5)
 
 class Library(object):
     """
